summaryrefslogtreecommitdiffstats
path: root/source
diff options
context:
space:
mode:
Diffstat (limited to 'source')
-rwxr-xr-xsource/a/sysklogd/sysklogd.SlackBuild2
-rwxr-xr-xsource/e/emacspeak/emacspeak.SlackBuild13
-rw-r--r--source/installer/ChangeLog.txt3
-rwxr-xr-xsource/installer/build_installer.sh3
-rw-r--r--source/k/kernel-configs/config-generic-6.9.2 (renamed from source/k/kernel-configs/config-generic-6.9.1)2
-rw-r--r--source/k/kernel-configs/config-generic-6.9.2.x64 (renamed from source/k/kernel-configs/config-generic-6.9.1.x64)2
-rw-r--r--source/k/kernel-configs/config-huge-6.9.2 (renamed from source/k/kernel-configs/config-huge-6.9.1)2
-rw-r--r--source/k/kernel-configs/config-huge-6.9.2.x64 (renamed from source/k/kernel-configs/config-huge-6.9.1.x64)2
-rw-r--r--source/kde/kde/build/calligra2
-rw-r--r--source/kde/kde/build/krita2
-rw-r--r--source/kde/kde/build/kstars2
-rw-r--r--source/kde/kde/build/step2
-rwxr-xr-xsource/kde/libindi/libindi.SlackBuild2
-rwxr-xr-xsource/kde/stellarsolver/stellarsolver.SlackBuild2
-rw-r--r--source/l/glib2/4073.patch290
-rwxr-xr-xsource/l/glib2/glib2.SlackBuild5
-rw-r--r--source/l/pipewire/pipewire.url2
-rwxr-xr-xsource/n/ntp/ntp.SlackBuild2
-rw-r--r--source/x/x11/build/igt-gpu-tools2
-rwxr-xr-xsource/xap/sane/sane.SlackBuild8
-rwxr-xr-xsource/xap/xsnow/xsnow.SlackBuild2
21 files changed, 329 insertions, 23 deletions
diff --git a/source/a/sysklogd/sysklogd.SlackBuild b/source/a/sysklogd/sysklogd.SlackBuild
index 18db0b66d..bec356e8c 100755
--- a/source/a/sysklogd/sysklogd.SlackBuild
+++ b/source/a/sysklogd/sysklogd.SlackBuild
@@ -157,7 +157,7 @@ cp -a \
# If there's a ChangeLog, installing at least part of the recent history
# is useful, but don't let it get totally out of control:
-if [ -r ChangeLog ]; then
+if [ -r ChangeLog.md ]; then
DOCSDIR=$(echo $PKG/usr/doc/${PKGNAM}-$VERSION)
cat ChangeLog.md | head -n 1000 > $DOCSDIR/ChangeLog.md
touch -r ChangeLog.md $DOCSDIR/ChangeLog.md
diff --git a/source/e/emacspeak/emacspeak.SlackBuild b/source/e/emacspeak/emacspeak.SlackBuild
index 7c45f0ffb..800e00fa5 100755
--- a/source/e/emacspeak/emacspeak.SlackBuild
+++ b/source/e/emacspeak/emacspeak.SlackBuild
@@ -24,7 +24,7 @@ cd $(dirname $0) ; CWD=$(pwd)
PKGNAM=emacspeak
VERSION=${VERSION:-$(echo $PKGNAM-*.tar.?z | rev | cut -f 3- -d . | cut -f 1 -d - | rev)}
-BUILD=${BUILD:-1}
+BUILD=${BUILD:-2}
# Automatically determine the architecture we're building on:
if [ -z "$ARCH" ]; then
@@ -146,8 +146,17 @@ mkdir -p $PKG/usr/doc/${PKGNAM}-$VERSION
ln -sf /usr/share/emacs/site-lisp/emacspeak/etc .
ln -sf etc/COPYRIGHT .
ln -sf etc/NEWS .
- ln -sf /usr/share/emacs/site-lisp/emacspeak/README.md .
+ ln -sf /usr/share/emacs/site-lisp/emacspeak/README .
+ ln -sf /usr/share/emacs/site-lisp/emacspeak/Readme.org .
ln -sf /usr/share/emacs/site-lisp/emacspeak/blog-archive .
+ # Check these:
+ find $PKG/usr/doc/${PKGNAM}-$VERSION -xtype l | while read brokenlink ; do
+ echo
+ echo "WARNING: Removing broken symlink $brokenlink"
+ echo
+ rm -f $brokenlink
+ sleep 60
+ done
)
mkdir -p $PKG/install
diff --git a/source/installer/ChangeLog.txt b/source/installer/ChangeLog.txt
index 48c4bd76e..88af5d041 100644
--- a/source/installer/ChangeLog.txt
+++ b/source/installer/ChangeLog.txt
@@ -1,3 +1,6 @@
+Sat May 25 17:39:17 UTC 2024
+ Add zram.ko.
++--------------------------+
Wed May 15 22:32:33 UTC 2024
Force compress the hwdata files. Thanks to Stuart Winter.
Include rescan_scsi_bus.sh, sg_inq, sg_turs, and libsgutils2 from the
diff --git a/source/k/kernel-configs/config-generic-6.9.1 b/source/k/kernel-configs/config-generic-6.9.2
index 8ac2f0db2..d7c3168b0 100644
--- a/source/k/kernel-configs/config-generic-6.9.1
+++ b/source/k/kernel-configs/config-generic-6.9.2
@@ -1,6 +1,6 @@
#
# Automatically generated file; DO NOT EDIT.
-# Linux/x86 6.9.1 Kernel Configuration
+# Linux/x86 6.9.2 Kernel Configuration
#
CONFIG_CC_VERSION_TEXT="gcc (GCC) 14.1.0"
CONFIG_CC_IS_GCC=y
diff --git a/source/k/kernel-configs/config-generic-6.9.1.x64 b/source/k/kernel-configs/config-generic-6.9.2.x64
index a4658e667..f22505513 100644
--- a/source/k/kernel-configs/config-generic-6.9.1.x64
+++ b/source/k/kernel-configs/config-generic-6.9.2.x64
@@ -1,6 +1,6 @@
#
# Automatically generated file; DO NOT EDIT.
-# Linux/x86 6.9.1 Kernel Configuration
+# Linux/x86 6.9.2 Kernel Configuration
#
CONFIG_CC_VERSION_TEXT="gcc (GCC) 14.1.0"
CONFIG_CC_IS_GCC=y
diff --git a/source/k/kernel-configs/config-huge-6.9.1 b/source/k/kernel-configs/config-huge-6.9.2
index ce091cf7c..9c7cb520f 100644
--- a/source/k/kernel-configs/config-huge-6.9.1
+++ b/source/k/kernel-configs/config-huge-6.9.2
@@ -1,6 +1,6 @@
#
# Automatically generated file; DO NOT EDIT.
-# Linux/x86 6.9.1 Kernel Configuration
+# Linux/x86 6.9.2 Kernel Configuration
#
CONFIG_CC_VERSION_TEXT="gcc (GCC) 14.1.0"
CONFIG_CC_IS_GCC=y
diff --git a/source/k/kernel-configs/config-huge-6.9.1.x64 b/source/k/kernel-configs/config-huge-6.9.2.x64
index 8584d5d8e..9e0f543c2 100644
--- a/source/k/kernel-configs/config-huge-6.9.1.x64
+++ b/source/k/kernel-configs/config-huge-6.9.2.x64
@@ -1,6 +1,6 @@
#
# Automatically generated file; DO NOT EDIT.
-# Linux/x86 6.9.1 Kernel Configuration
+# Linux/x86 6.9.2 Kernel Configuration
#
CONFIG_CC_VERSION_TEXT="gcc (GCC) 14.1.0"
CONFIG_CC_IS_GCC=y
diff --git a/source/kde/kde/build/calligra b/source/kde/kde/build/calligra
index a2720097d..425151f3a 100644
--- a/source/kde/kde/build/calligra
+++ b/source/kde/kde/build/calligra
@@ -1 +1 @@
-39
+40
diff --git a/source/kde/kde/build/krita b/source/kde/kde/build/krita
index ec635144f..f599e28b8 100644
--- a/source/kde/kde/build/krita
+++ b/source/kde/kde/build/krita
@@ -1 +1 @@
-9
+10
diff --git a/source/kde/kde/build/kstars b/source/kde/kde/build/kstars
index d00491fd7..0cfbf0888 100644
--- a/source/kde/kde/build/kstars
+++ b/source/kde/kde/build/kstars
@@ -1 +1 @@
-1
+2
diff --git a/source/kde/kde/build/step b/source/kde/kde/build/step
index 0cfbf0888..00750edc0 100644
--- a/source/kde/kde/build/step
+++ b/source/kde/kde/build/step
@@ -1 +1 @@
-2
+3
diff --git a/source/kde/libindi/libindi.SlackBuild b/source/kde/libindi/libindi.SlackBuild
index cf32b36a3..594c9b550 100755
--- a/source/kde/libindi/libindi.SlackBuild
+++ b/source/kde/libindi/libindi.SlackBuild
@@ -25,7 +25,7 @@ cd $(dirname $0) ; CWD=$(pwd)
PKGNAM=libindi
SRCNAM=indi
VERSION=${VERSION:-$(echo $SRCNAM-*.tar.?z | rev | cut -f 3- -d . | cut -f 1 -d - | rev)}
-BUILD=${BUILD:-1}
+BUILD=${BUILD:-2}
# Automatically determine the architecture we're building on:
if [ -z "$ARCH" ]; then
diff --git a/source/kde/stellarsolver/stellarsolver.SlackBuild b/source/kde/stellarsolver/stellarsolver.SlackBuild
index 8fa52b301..f1477c3ed 100755
--- a/source/kde/stellarsolver/stellarsolver.SlackBuild
+++ b/source/kde/stellarsolver/stellarsolver.SlackBuild
@@ -24,7 +24,7 @@ cd $(dirname $0) ; CWD=$(pwd)
PKGNAM=stellarsolver
VERSION=${VERSION:-$(echo $PKGNAM-*.tar.?z | rev | cut -f 3- -d . | cut -f 1 -d - | rev)}
-BUILD=${BUILD:-1}
+BUILD=${BUILD:-2}
# Automatically determine the architecture we're building on:
if [ -z "$ARCH" ]; then
diff --git a/source/l/glib2/4073.patch b/source/l/glib2/4073.patch
new file mode 100644
index 000000000..24156369b
--- /dev/null
+++ b/source/l/glib2/4073.patch
@@ -0,0 +1,290 @@
+From df2c5d925ac4b8f1708bafa5ac1d35acada05d55 Mon Sep 17 00:00:00 2001
+From: Philip Withnall <pwithnall@gnome.org>
+Date: Wed, 15 May 2024 12:26:36 +0100
+Subject: [PATCH 1/2] gmenuexporter: Fix a NULL pointer dereference on an error
+ handling path
+MIME-Version: 1.0
+Content-Type: text/plain; charset=UTF-8
+Content-Transfer-Encoding: 8bit
+
+This latent bug wasn’t triggered until commit 3f30ec86c (or its
+cherry-pick onto `glib-2-80`, 747e3af99, which was first released in
+2.80.1).
+
+That change means that `g_menu_exporter_free()` is now called on the
+registration failure path by `g_dbus_connection_register_object()`
+before it returns. The caller then tries to call `g_slice_free()` on the
+exporter again. The call to `g_menu_exporter_free()` tries to
+dereference/free members of the exporter which it expects to be
+initialised — but because this is happening in an error handling path,
+they are not initialised.
+
+If it were to get any further, the `g_slice_free()` would then be a
+double-free on the exporter allocation.
+
+Fix that by making `g_menu_exporter_free()` robust to some of the
+exporter members being `NULL`, and moving some of the initialisation
+code higher in `g_dbus_connection_export_menu_model()`, and removing the
+duplicate free code on the error handling path.
+
+This includes a unit test.
+
+Signed-off-by: Philip Withnall <pwithnall@gnome.org>
+
+Fixes: #3366
+---
+ gio/gmenuexporter.c | 23 ++++++++---------------
+ gio/tests/gmenumodel.c | 37 +++++++++++++++++++++++++++++++++++++
+ 2 files changed, 45 insertions(+), 15 deletions(-)
+
+diff --git a/gio/gmenuexporter.c b/gio/gmenuexporter.c
+index 909780cb2c..1d4db13523 100644
+--- a/gio/gmenuexporter.c
++++ b/gio/gmenuexporter.c
+@@ -707,11 +707,9 @@ g_menu_exporter_create_group (GMenuExporter *exporter)
+ }
+
+ static void
+-g_menu_exporter_free (gpointer user_data)
++g_menu_exporter_free (GMenuExporter *exporter)
+ {
+- GMenuExporter *exporter = user_data;
+-
+- g_menu_exporter_menu_free (exporter->root);
++ g_clear_pointer (&exporter->root, g_menu_exporter_menu_free);
+ g_clear_pointer (&exporter->peer_remote, g_menu_exporter_remote_free);
+ g_hash_table_unref (exporter->remotes);
+ g_hash_table_unref (exporter->groups);
+@@ -794,21 +792,16 @@ g_dbus_connection_export_menu_model (GDBusConnection *connection,
+ guint id;
+
+ exporter = g_slice_new0 (GMenuExporter);
+-
+- id = g_dbus_connection_register_object (connection, object_path, org_gtk_Menus_get_interface (),
+- &vtable, exporter, g_menu_exporter_free, error);
+-
+- if (id == 0)
+- {
+- g_slice_free (GMenuExporter, exporter);
+- return 0;
+- }
+-
+ exporter->connection = g_object_ref (connection);
+ exporter->object_path = g_strdup (object_path);
+ exporter->groups = g_hash_table_new (NULL, NULL);
+ exporter->remotes = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_menu_exporter_remote_free);
+- exporter->root = g_menu_exporter_group_add_menu (g_menu_exporter_create_group (exporter), menu);
++
++ id = g_dbus_connection_register_object (connection, object_path, org_gtk_Menus_get_interface (),
++ &vtable, exporter, (GDestroyNotify) g_menu_exporter_free, error);
++
++ if (id != 0)
++ exporter->root = g_menu_exporter_group_add_menu (g_menu_exporter_create_group (exporter), menu);
+
+ return id;
+ }
+diff --git a/gio/tests/gmenumodel.c b/gio/tests/gmenumodel.c
+index d75f36a297..22d1b4d61e 100644
+--- a/gio/tests/gmenumodel.c
++++ b/gio/tests/gmenumodel.c
+@@ -1159,6 +1159,42 @@ test_dbus_peer_subscriptions (void)
+ #endif
+ }
+
++static void
++test_dbus_export_error_handling (void)
++{
++ GRand *rand = NULL;
++ RandomMenu *menu = NULL;
++ GDBusConnection *bus;
++ GError *local_error = NULL;
++ guint id1, id2;
++
++ g_test_summary ("Test that error handling of menu model export failure works");
++ g_test_bug ("https://gitlab.gnome.org/GNOME/glib/-/issues/3366");
++
++ bus = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
++
++ rand = g_rand_new_with_seed (g_test_rand_int ());
++ menu = random_menu_new (rand, 2);
++
++ id1 = g_dbus_connection_export_menu_model (bus, "/", G_MENU_MODEL (menu), &local_error);
++ g_assert_no_error (local_error);
++ g_assert_cmpuint (id1, !=, 0);
++
++ /* Trigger a failure by trying to export on a path which is already in use */
++ id2 = g_dbus_connection_export_menu_model (bus, "/", G_MENU_MODEL (menu), &local_error);
++ g_assert_error (local_error, G_IO_ERROR, G_IO_ERROR_EXISTS);
++ g_assert_cmpuint (id2, ==, 0);
++ g_clear_error (&local_error);
++
++ g_dbus_connection_unexport_menu_model (bus, id1);
++
++ while (g_main_context_iteration (NULL, FALSE));
++
++ g_clear_object (&menu);
++ g_rand_free (rand);
++ g_clear_object (&bus);
++}
++
+ static gpointer
+ do_modify (gpointer data)
+ {
+@@ -1658,6 +1694,7 @@ main (int argc, char **argv)
+ g_test_add_func ("/gmenu/dbus/threaded", test_dbus_threaded);
+ g_test_add_func ("/gmenu/dbus/peer/roundtrip", test_dbus_peer_roundtrip);
+ g_test_add_func ("/gmenu/dbus/peer/subscriptions", test_dbus_peer_subscriptions);
++ g_test_add_func ("/gmenu/dbus/export/error-handling", test_dbus_export_error_handling);
+ g_test_add_func ("/gmenu/attributes", test_attributes);
+ g_test_add_func ("/gmenu/attributes/iterate", test_attribute_iter);
+ g_test_add_func ("/gmenu/links", test_links);
+--
+GitLab
+
+
+From 7a7137838e79e5a98e6f4eab6898e2a0dc6392cd Mon Sep 17 00:00:00 2001
+From: Philip Withnall <pwithnall@gnome.org>
+Date: Wed, 15 May 2024 14:00:09 +0100
+Subject: [PATCH 2/2] gactiongroupexporter: Fix memory problems on an error
+ handling path
+
+Almost identically to the previous commit, fix a similar latent bug in
+`g_dbus_connection_export_action_group()`, which was not ready to handle
+the fledgling `GActionGroupExporter` being freed early on an error
+handling path.
+
+See the previous commit message for details of the approach.
+
+This includes a unit test.
+
+Signed-off-by: Philip Withnall <pwithnall@gnome.org>
+
+Fixes: #3366
+---
+ gio/gactiongroupexporter.c | 35 ++++++++++++++------------------
+ gio/tests/actions.c | 41 ++++++++++++++++++++++++++++++++++++++
+ 2 files changed, 56 insertions(+), 20 deletions(-)
+
+diff --git a/gio/gactiongroupexporter.c b/gio/gactiongroupexporter.c
+index 3ec1db224e..1e253ec88b 100644
+--- a/gio/gactiongroupexporter.c
++++ b/gio/gactiongroupexporter.c
+@@ -531,10 +531,8 @@ org_gtk_Actions_method_call (GDBusConnection *connection,
+ }
+
+ static void
+-g_action_group_exporter_free (gpointer user_data)
++g_action_group_exporter_free (GActionGroupExporter *exporter)
+ {
+- GActionGroupExporter *exporter = user_data;
+-
+ g_signal_handlers_disconnect_by_func (exporter->action_group,
+ g_action_group_exporter_action_added, exporter);
+ g_signal_handlers_disconnect_by_func (exporter->action_group,
+@@ -616,15 +614,6 @@ g_dbus_connection_export_action_group (GDBusConnection *connection,
+ }
+
+ exporter = g_slice_new (GActionGroupExporter);
+- id = g_dbus_connection_register_object (connection, object_path, org_gtk_Actions, &vtable,
+- exporter, g_action_group_exporter_free, error);
+-
+- if (id == 0)
+- {
+- g_slice_free (GActionGroupExporter, exporter);
+- return 0;
+- }
+-
+ exporter->context = g_main_context_ref_thread_default ();
+ exporter->pending_changes = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+ exporter->pending_source = NULL;
+@@ -632,14 +621,20 @@ g_dbus_connection_export_action_group (GDBusConnection *connection,
+ exporter->connection = g_object_ref (connection);
+ exporter->object_path = g_strdup (object_path);
+
+- g_signal_connect (action_group, "action-added",
+- G_CALLBACK (g_action_group_exporter_action_added), exporter);
+- g_signal_connect (action_group, "action-removed",
+- G_CALLBACK (g_action_group_exporter_action_removed), exporter);
+- g_signal_connect (action_group, "action-state-changed",
+- G_CALLBACK (g_action_group_exporter_action_state_changed), exporter);
+- g_signal_connect (action_group, "action-enabled-changed",
+- G_CALLBACK (g_action_group_exporter_action_enabled_changed), exporter);
++ id = g_dbus_connection_register_object (connection, object_path, org_gtk_Actions, &vtable,
++ exporter, (GDestroyNotify) g_action_group_exporter_free, error);
++
++ if (id != 0)
++ {
++ g_signal_connect (action_group, "action-added",
++ G_CALLBACK (g_action_group_exporter_action_added), exporter);
++ g_signal_connect (action_group, "action-removed",
++ G_CALLBACK (g_action_group_exporter_action_removed), exporter);
++ g_signal_connect (action_group, "action-state-changed",
++ G_CALLBACK (g_action_group_exporter_action_state_changed), exporter);
++ g_signal_connect (action_group, "action-enabled-changed",
++ G_CALLBACK (g_action_group_exporter_action_enabled_changed), exporter);
++ }
+
+ return id;
+ }
+diff --git a/gio/tests/actions.c b/gio/tests/actions.c
+index a24c52c5e4..2b7a100fcf 100644
+--- a/gio/tests/actions.c
++++ b/gio/tests/actions.c
+@@ -1125,6 +1125,46 @@ test_dbus_export (void)
+ session_bus_down ();
+ }
+
++static void
++test_dbus_export_error_handling (void)
++{
++ GDBusConnection *bus = NULL;
++ GSimpleActionGroup *group = NULL;
++ GError *local_error = NULL;
++ guint id1, id2;
++
++ g_test_summary ("Test that error handling of action group export failure works");
++ g_test_bug ("https://gitlab.gnome.org/GNOME/glib/-/issues/3366");
++
++ session_bus_up ();
++ bus = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
++
++ group = g_simple_action_group_new ();
++ g_simple_action_group_add_entries (group,
++ exported_entries,
++ G_N_ELEMENTS (exported_entries),
++ NULL);
++
++ id1 = g_dbus_connection_export_action_group (bus, "/", G_ACTION_GROUP (group), &local_error);
++ g_assert_no_error (local_error);
++ g_assert_cmpuint (id1, !=, 0);
++
++ /* Trigger a failure by trying to export on a path which is already in use */
++ id2 = g_dbus_connection_export_action_group (bus, "/", G_ACTION_GROUP (group), &local_error);
++ g_assert_error (local_error, G_IO_ERROR, G_IO_ERROR_EXISTS);
++ g_assert_cmpuint (id2, ==, 0);
++ g_clear_error (&local_error);
++
++ g_dbus_connection_unexport_action_group (bus, id1);
++
++ while (g_main_context_iteration (NULL, FALSE));
++
++ g_object_unref (group);
++ g_object_unref (bus);
++
++ session_bus_down ();
++}
++
+ static gpointer
+ do_export (gpointer data)
+ {
+@@ -1448,6 +1488,7 @@ main (int argc, char **argv)
+ g_test_add_func ("/actions/entries", test_entries);
+ g_test_add_func ("/actions/parse-detailed", test_parse_detailed);
+ g_test_add_func ("/actions/dbus/export", test_dbus_export);
++ g_test_add_func ("/actions/dbus/export/error-handling", test_dbus_export_error_handling);
+ g_test_add_func ("/actions/dbus/threaded", test_dbus_threaded);
+ g_test_add_func ("/actions/dbus/bug679509", test_bug679509);
+ g_test_add_func ("/actions/property", test_property_actions);
+--
+GitLab
+
diff --git a/source/l/glib2/glib2.SlackBuild b/source/l/glib2/glib2.SlackBuild
index 83bb0ba32..6ad62007b 100755
--- a/source/l/glib2/glib2.SlackBuild
+++ b/source/l/glib2/glib2.SlackBuild
@@ -24,7 +24,7 @@ cd $(dirname $0) ; CWD=$(pwd)
PKGNAM=glib2
VERSION=${VERSION:-$(echo glib-*.tar.?z* | rev | cut -f 3- -d . | cut -f 1 -d - | rev)}
-BUILD=${BUILD:-1}
+BUILD=${BUILD:-2}
NUMJOBS=${NUMJOBS:-" -j$(expr $(nproc) + 1) "}
@@ -77,6 +77,9 @@ find . \
\( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
-exec chmod 644 {} \+
+# Patch regressions:
+cat $CWD/4073.patch | patch -p1 --verbose || exit 1
+
# Configure, build, and install:
export CFLAGS="$SLKCFLAGS"
export CXXFLAGS="$SLKCFLAGS"
diff --git a/source/l/pipewire/pipewire.url b/source/l/pipewire/pipewire.url
index 8bcd14c19..74aa879fd 100644
--- a/source/l/pipewire/pipewire.url
+++ b/source/l/pipewire/pipewire.url
@@ -1,2 +1,2 @@
https://gitlab.freedesktop.org/pipewire/pipewire
-https://gitlab.freedesktop.org/pipewire/pipewire/-/archive/1.0.6/pipewire-1.0.6.tar.gz
+https://gitlab.freedesktop.org/pipewire/pipewire/-/archive/1.0.7/pipewire-1.0.7.tar.gz
diff --git a/source/n/ntp/ntp.SlackBuild b/source/n/ntp/ntp.SlackBuild
index 4433a4b35..b0677d54f 100755
--- a/source/n/ntp/ntp.SlackBuild
+++ b/source/n/ntp/ntp.SlackBuild
@@ -24,7 +24,7 @@ cd $(dirname $0) ; CWD=$(pwd)
PKGNAM=ntp
VERSION=${VERSION:-$(echo $PKGNAM-*.tar.?z* | rev | cut -f 3- -d . | cut -f 1 -d - | rev)}
-BUILD=${BUILD:-3}
+BUILD=${BUILD:-1}
# Automatically determine the architecture we're building on:
if [ -z "$ARCH" ]; then
diff --git a/source/x/x11/build/igt-gpu-tools b/source/x/x11/build/igt-gpu-tools
index 0cfbf0888..00750edc0 100644
--- a/source/x/x11/build/igt-gpu-tools
+++ b/source/x/x11/build/igt-gpu-tools
@@ -1 +1 @@
-2
+3
diff --git a/source/xap/sane/sane.SlackBuild b/source/xap/sane/sane.SlackBuild
index 472aa849b..d8e40d7f3 100755
--- a/source/xap/sane/sane.SlackBuild
+++ b/source/xap/sane/sane.SlackBuild
@@ -23,7 +23,7 @@
cd $(dirname $0) ; CWD=$(pwd)
PKGNAM=sane
-BACKVER=1.3.0
+BACKVER=1.3.1
FRONTVER=1.0.14
VERSION=${VERSION:-$BACKVER}
BUILD=${BUILD:-1}
@@ -73,9 +73,9 @@ mkdir -p $TMP $PKG
# First, we'll build the backends
cd $TMP
-rm -rf backends-$BACKVER
-tar xvf $CWD/backends-$BACKVER.tar.?z || exit 1
-cd backends-$BACKVER || exit 1
+rm -rf sane-backends-$BACKVER
+tar xvf $CWD/sane-backends-$BACKVER.tar.?z || exit 1
+cd sane-backends-$BACKVER || exit 1
chown -R root:root .
# Put the SANE_CAP_ALWAYS_SETTABLE definition back until
diff --git a/source/xap/xsnow/xsnow.SlackBuild b/source/xap/xsnow/xsnow.SlackBuild
index def5c0d2f..dc4f87749 100755
--- a/source/xap/xsnow/xsnow.SlackBuild
+++ b/source/xap/xsnow/xsnow.SlackBuild
@@ -24,7 +24,7 @@ cd $(dirname $0) ; CWD=$(pwd)
PKGNAM=xsnow
VERSION=${VERSION:-$(echo $PKGNAM-*.tar.?z | rev | cut -f 3- -d . | cut -f 1 -d - | rev)}
-BUILD=${BUILD:-1}
+BUILD=${BUILD:-2}
# Automatically determine the architecture we're building on:
if [ -z "$ARCH" ]; then
diff --git a/source/installer/build_installer.sh b/source/installer/build_installer.sh
index 9eb4de3b1..fb31963fc 100755
--- a/source/installer/build_installer.sh
+++ b/source/installer/build_installer.sh
@@ -1716,12 +1716,13 @@ for ind in $(seq 0 $((${#KERNELS[*]} -1)) ); do
rm -rf${VERBOSE1} md.orig
;;
esac
# Save loop.ko, nvme.ko, and virtio_blk.ko, but remove other block drivers:
mv block block.orig
mkdir block
mv block.orig/nvme.ko block
mv block.orig/loop.ko block
mv block.orig/virtio_blk.ko block
+ mv block.orig/zram block
rm -rf${VERBOSE1} block.orig
# Done with block directory
# Grab a few modules from staging:
@@ -1716,12 +1716,13 @@ for ind in $(seq 0 $((${#KERNELS[*]} -1)) ); do
;;
esac
- # Save loop.ko, nvme.ko, and virtio_blk.ko, but remove other block drivers:
+ # Save loop.ko, nvme.ko, virtio_blk.ko, and zram.ko, but remove other block drivers:
mv block block.orig
mkdir block